
from shinsapp import SHINSApp
from util.shinsLogger import logger
from alignment.allineamento import Align_the_coronagraph as aly
from alignment.utils import read_image
from util import exception
from util import functions as ufun
from util import variables as uvars
import Basda
import numpy as np
import time

# Other templates
from SHARKNIR_gen_base import SHARKNIR_gen_base

class SHARKNIR_cal_Flux_MaskRemoval(SHINSApp):

    @exception.handler_for_run
    def run(self, ins_s=None, det_s=None, tel_s=None, rtc_s=None, **kwargs):
        '''template to align PSF on masks. Steps:

        . Read the named position of CORO_SLIT_W to determined the mask being using and save it
        
        . Set the CORO_SLIT_W to WINDOW to remove the mask
        . Instrument Setup and SASHA Setup
        . Expose SASHA
        . Retrive FITS file
        
        . Put back the mask as in the previous configuration
        . Instrument Setup without taking image
        
        . End of Template
        
        '''
        
        logger.info(__name__)
        self.status = uvars.EXIT_SUCCESS
        obsController = self.obsController

        fitsDir = uvars.fitsDir + obsController.getCurrentDataDirectory() +'/'

        self.gen_base = SHARKNIR_gen_base();        gen_base = self.gen_base
        
        coro_mask = ins_s["CORO_SLIT_W"]
        ins_s["CORO_SLIT_W"] = "WINDOW"
        logger.debug("Saving current Coro Mask position and putting the wheel in {}".format(ins_s['CORO_SLIT_W']))
        
        #################
        # Setup + image #
        #################

        logger.info("Waiting setup to acquire image without the mask ...")
        self.status, self.filenames, _ = gen_base.main(ins_s=ins_s, det_s=det_s, **kwargs)
        logger.info("Waiting setup to acquire image without the mask ... DONE")

        ins_s["CORO_SLIT_W"] = coro_mask

        #################
        # Setup + image #
        #################

        logger.info("Waiting setup to put back the previous coro mask ...")
        self.status, _, __ = gen_base.main(ins_s=ins_s, expose=False)
        logger.info("Waiting setup to put back the previous coro mask ... DONE")

        
        
